Examples
#########


Dask
====
.. toctree::
   :maxdepth: 1

   examples/dask/efficient_dask.ipynb

Pre-Processing
==============
.. toctree::
   :maxdepth: 1

   examples/preprocessing/setup_your_own_data.ipynb

Subseasonal
===========
.. toctree::
   :maxdepth: 1

   examples/subseasonal/daily-subx-example.ipynb
   examples/subseasonal/weekly-subx-example.ipynb


Monthly and Seasonal
====================
.. toctree::
   :maxdepth: 1

   examples/monseas/monthly-enso-subx-example.ipynb
   examples/monseas/seasonal-enso-subx-example.ipynb


Decadal
===================
.. toctree::
   :maxdepth: 1

   examples/decadal/perfect-model-predictability-demo.ipynb
   examples/decadal/tropical-pacific-ssts.ipynb
   examples/decadal/diagnose-potential-predictability.ipynb
   examples/decadal/smoothing.ipynb
   examples/decadal/Significance.ipynb
